library verilog;
use verilog.vl_types.all;
entity dfi_phy_core is
    generic(
        NUM_DATA_SLICES : integer := 5;
        PHY_CORE_WIDTH  : integer := 80;
        PHY_DQ_WIDTH    : integer := 8;
        PHY_DRAM_WIDTH  : vl_notype;
        UNUSED_SLICE_BITS: vl_notype;
        NUM_MDLL        : vl_notype;
        NUM_RANKS       : integer := 1;
        CLKSIZE         : integer := 1;
        PHY_CTRL_CMD_BITS_PER_SLICE: integer := 26;
        PHY_CTRL_CMD_BITS: vl_notype;
        NUM_PHY_CTRL_SLICES: integer := 1;
        NUM_PHY_CTRL_ZERO: integer := 0;
        NUM_FIFO_WE_OUT_DELAYS: vl_notype;
        NUM_FIFO_WE     : vl_notype
    );
    port(
        core_clk        : in     vl_logic;
        rstn_p          : in     vl_logic;
        rstn_n          : in     vl_logic;
        reg_phy_dis_phy_ctrl_rstn: in     vl_logic;
        scan_enable     : in     vl_logic;
        scan_in0        : in     vl_logic;
        scan_out0       : out    vl_logic;
        scan_in1        : in     vl_logic;
        scan_out1       : out    vl_logic;
        scan_in2        : in     vl_logic;
        scan_out2       : out    vl_logic;
        scan_in3        : in     vl_logic;
        scan_out3       : out    vl_logic;
        scan_in4        : in     vl_logic;
        scan_out4       : out    vl_logic;
        scan_in5        : in     vl_logic;
        scan_out5       : out    vl_logic;
        ddrc_dfi_cs_n   : in     vl_logic_vector;
        ddrc_dfi_bank   : in     vl_logic_vector(2 downto 0);
        ddrc_dfi_address: in     vl_logic_vector(15 downto 0);
        ddrc_dfi_cas_n  : in     vl_logic;
        ddrc_dfi_ras_n  : in     vl_logic;
        ddrc_dfi_we_n   : in     vl_logic;
        ddrc_dfi_cke    : in     vl_logic_vector;
        ddrc_dfi_odt    : in     vl_logic_vector;
        ddrc_dfi_reset_n: in     vl_logic_vector;
        ddrc_dfi_wrdata : in     vl_logic_vector;
        ddrc_dfi_wrdata_en: in     vl_logic_vector;
        ddrc_dfi_wrdata_mask: in     vl_logic_vector;
        phy_dfi_rddata  : out    vl_logic_vector;
        phy_dfi_rddata_dm: out    vl_logic_vector;
        phy_dfi_rddata_valid: out    vl_logic;
        ddrc_dfi_rddata_en: in     vl_logic_vector;
        ddrc_dfi_ctrlupd_req: in     vl_logic;
        phy_dfi_ctrlupd_ack: out    vl_logic;
        phy_dfi_init_complete: out    vl_logic;
        ddrc_dfi_dram_clk_disable: in     vl_logic_vector;
        phy_dfi_rdlvl_mode: out    vl_logic_vector(1 downto 0);
        ddrc_dfi_rdlvl_en: in     vl_logic_vector;
        phy_dfi_rdlvl_resp: out    vl_logic_vector;
        ddrc_dfi_rdlvl_cs_n: in     vl_logic_vector;
        ddrc_dfi_rdlvl_edge: in     vl_logic;
        phy_dfi_rdlvl_gate_mode: out    vl_logic_vector(1 downto 0);
        ddrc_dfi_rdlvl_gate_en: in     vl_logic_vector;
        phy_dfi_wrlvl_mode: out    vl_logic_vector(1 downto 0);
        phy_dfi_wrlvl_resp: out    vl_logic_vector;
        ddrc_dfi_wrlvl_en: in     vl_logic_vector;
        ddrc_dfi_wrlvl_cs_n: in     vl_logic_vector;
        ddrc_dfi_wrlvl_strobe: in     vl_logic;
        reg_phy_gatelvl_num_of_dq0: in     vl_logic_vector(3 downto 0);
        reg_phy_wrlvl_num_of_dq0: in     vl_logic_vector(3 downto 0);
        reg_phy_rdlvl_inc_mode: in     vl_logic_vector;
        phy_reg_rdlvl_inc_fail: out    vl_logic_vector;
        reg_phy_wrlvl_inc_mode: in     vl_logic_vector;
        phy_reg_wrlvl_inc_fail: out    vl_logic_vector;
        reg_phy_gatelvl_inc_mode: in     vl_logic_vector;
        phy_reg_gatelvl_inc_fail: out    vl_logic_vector;
        reg_phy_loopback: in     vl_logic;
        reg_phy_bl2     : in     vl_logic;
        reg_phy_at_spd_atpg: in     vl_logic;
        reg_phy_clk_stall_level: in     vl_logic;
        reg_phy_cmd_latency: in     vl_logic;
        reg_phy_board_lpbk_tx: in     vl_logic_vector;
        reg_phy_board_lpbk_rx: in     vl_logic_vector;
        reg_phy_bist_enable: in     vl_logic;
        reg_phy_bist_force_err: in     vl_logic;
        reg_phy_bist_mode: in     vl_logic_vector(1 downto 0);
        reg_phy_bist_shift_dq: in     vl_logic_vector;
        reg_phy_bist_err_clr: in     vl_logic_vector;
        phy_reg_bist_err: out    vl_logic_vector;
        reg_phy_invert_clkout: in     vl_logic;
        reg_phy_dq_offset: in     vl_logic_vector;
        reg_phy_gatelvl_init_ratio: in     vl_logic_vector;
        reg_phy_gatelvl_init_mode: in     vl_logic;
        reg_phy_wrlvl_init_ratio: in     vl_logic_vector;
        reg_phy_wrlvl_init_mode: in     vl_logic;
        phy_reg_wrlvl_dqs_ratio: out    vl_logic_vector;
        phy_reg_wrlvl_dq_ratio: out    vl_logic_vector;
        phy_reg_rdlvl_dqs_ratio: out    vl_logic_vector;
        phy_reg_wr_level_fsm: out    vl_logic_vector;
        phy_reg_rd_level_fsm: out    vl_logic_vector;
        phy_reg_rdlvl_fifowein_ratio: out    vl_logic_vector;
        phy_reg_gate_level_fsm: out    vl_logic_vector;
        reg_phy_ctrl_slave_ratio: in     vl_logic_vector(9 downto 0);
        reg_phy_ctrl_slave_force: in     vl_logic;
        reg_phy_ctrl_slave_delay: in     vl_logic_vector(8 downto 0);
        reg_phy_rd_dqs_slave_ratio: in     vl_logic_vector;
        reg_phy_rd_dqs_slave_force: in     vl_logic_vector;
        reg_phy_rd_dqs_slave_delay: in     vl_logic_vector;
        reg_phy_wr_dqs_slave_ratio: in     vl_logic_vector;
        reg_phy_wr_dqs_slave_force: in     vl_logic_vector;
        reg_phy_wr_dqs_slave_delay: in     vl_logic_vector;
        reg_phy_fifo_we_slave_ratio: in     vl_logic_vector;
        reg_phy_fifo_we_in_force: in     vl_logic_vector;
        reg_phy_fifo_we_in_delay: in     vl_logic_vector;
        reg_phy_wr_data_slave_ratio: in     vl_logic_vector;
        reg_phy_wr_data_slave_force: in     vl_logic_vector;
        reg_phy_wr_data_slave_delay: in     vl_logic_vector;
        reg_phy_use_rank0_delays: in     vl_logic;
        reg_phy_wr_rl_delay: in     vl_logic_vector(4 downto 0);
        reg_phy_rd_rl_delay: in     vl_logic_vector(4 downto 0);
        reg_phy_dll_lock_diff: in     vl_logic_vector(3 downto 0);
        phy_reg_status_dll_lock: out    vl_logic_vector;
        phy_reg_status_dll_slave_value: out    vl_logic_vector;
        phy_reg_status_of_in_lock_state: out    vl_logic_vector;
        phy_reg_status_of_in_delay_value: out    vl_logic_vector;
        phy_reg_status_phy_ctrl_dll_lock: out    vl_logic;
        phy_reg_status_phy_ctrl_dll_slave_value: out    vl_logic_vector(8 downto 0);
        phy_reg_status_phy_ctrl_of_in_lock_state: out    vl_logic_vector(1 downto 0);
        phy_reg_status_phy_ctrl_of_in_delay_value: out    vl_logic_vector(8 downto 0);
        phy_reg_status_rd_dqs_slave_dll_value: out    vl_logic_vector;
        phy_reg_status_wr_data_slave_dll_value: out    vl_logic_vector;
        phy_reg_status_fifo_we_slave_dll_value: out    vl_logic_vector;
        phy_reg_status_phy_ctrl_slave_dll_value: out    vl_logic_vector(8 downto 0);
        phy_reg_status_wr_dqs_slave_dll_value: out    vl_logic_vector;
        reg_phy_use_wr_level: in     vl_logic;
        reg_phy_use_rd_data_eye_level: in     vl_logic;
        reg_phy_data_slice_in_use: in     vl_logic_vector;
        reg_phy_use_rd_dqs_gate_level: in     vl_logic;
        test_enable     : in     vl_logic;
        bs_difen        : in     vl_logic_vector(1 downto 0);
        bs_local_odt    : in     vl_logic_vector(1 downto 0);
        reg_phy_rd_local_odt: in     vl_logic_vector(1 downto 0);
        reg_phy_wr_local_odt: in     vl_logic_vector(1 downto 0);
        reg_phy_idle_local_odt: in     vl_logic_vector(1 downto 0);
        reg_phy_dis_calib_rst: in     vl_logic;
        reg_phy_rdc_fifo_rst_err_cnt_clr: in     vl_logic;
        phy_reg_rdc_fifo_rst_err_cnt: out    vl_logic_vector(3 downto 0);
        reg_phy_rdc_we_to_re_delay: in     vl_logic_vector(3 downto 0);
        reg_phy_use_fixed_re: in     vl_logic;
        reg_phy_lpddr   : in     vl_logic;
        reg_phy_dif_on  : in     vl_logic_vector(3 downto 0);
        reg_phy_dif_off : in     vl_logic_vector(3 downto 0);
        difen_dq0       : out    vl_logic_vector;
        difen_dq1       : out    vl_logic_vector;
        difen_dq2       : out    vl_logic_vector;
        difen_dq3       : out    vl_logic_vector;
        difen_dq4       : out    vl_logic_vector;
        difen_dq5       : out    vl_logic_vector;
        difen_dq6       : out    vl_logic_vector;
        difen_dq7       : out    vl_logic_vector;
        difen_dqs       : out    vl_logic_vector;
        difen_dm        : out    vl_logic_vector;
        bs_ctl_fifo_we_out: in     vl_logic_vector;
        bs_ctl_dq_out   : in     vl_logic_vector;
        bs_ctl_dq_oe    : in     vl_logic_vector;
        bs_ctl_dq_oeb   : in     vl_logic_vector;
        bs_ctl_dqs_out  : in     vl_logic_vector;
        bs_ctl_dqs_n_out: in     vl_logic_vector;
        bs_ctl_dqs_oe   : in     vl_logic_vector;
        bs_ctl_dqs_oeb  : in     vl_logic_vector;
        bs_ctl_dm_rdqs_out: in     vl_logic_vector;
        bs_ctl_dram_clk : in     vl_logic_vector;
        bs_ctl_dram_clk_n: in     vl_logic_vector;
        bs_ctl_dram_rstn: in     vl_logic_vector;
        bs_ctl_ba       : in     vl_logic_vector(2 downto 0);
        bs_ctl_addr     : in     vl_logic_vector(15 downto 0);
        bs_ctl_casn     : in     vl_logic;
        bs_ctl_rasn     : in     vl_logic;
        bs_ctl_wen      : in     vl_logic;
        bs_ctl_csn      : in     vl_logic_vector;
        bs_ctl_cke      : in     vl_logic_vector;
        bs_ctl_odt      : in     vl_logic_vector;
        bs_ctl_fifo_we_out_sel: in     vl_logic_vector;
        bs_ctl_dq_out_sel: in     vl_logic_vector;
        bs_ctl_dq_oe_sel: in     vl_logic_vector;
        bs_ctl_dq_oeb_sel: in     vl_logic_vector;
        bs_ctl_fifo_we_in_sel: in     vl_logic_vector;
        bs_ctl_dqs_out_sel: in     vl_logic_vector;
        bs_ctl_dqs_n_out_sel: in     vl_logic_vector;
        bs_ctl_dqs_oe_sel: in     vl_logic_vector;
        bs_ctl_dqs_oeb_sel: in     vl_logic_vector;
        bs_ctl_dm_rdqs_out_sel: in     vl_logic_vector;
        bs_ctl_dram_clk_sel: in     vl_logic_vector;
        bs_ctl_dram_rstn_sel: in     vl_logic_vector;
        bs_ctl_dram_clk_n_sel: in     vl_logic_vector;
        bs_ctl_ba_sel   : in     vl_logic_vector(2 downto 0);
        bs_ctl_addr_sel : in     vl_logic_vector(15 downto 0);
        bs_ctl_casn_sel : in     vl_logic;
        bs_ctl_rasn_sel : in     vl_logic;
        bs_ctl_wen_sel  : in     vl_logic;
        bs_ctl_csn_sel  : in     vl_logic_vector;
        bs_ctl_cke_sel  : in     vl_logic_vector;
        bs_ctl_odt_sel  : in     vl_logic_vector;
        bs_obs_fifo_we_in: out    vl_logic_vector;
        bs_obs_fifo_we_out: out    vl_logic_vector;
        bs_obs_dq_in    : out    vl_logic_vector;
        bs_obs_dq_out   : out    vl_logic_vector;
        bs_obs_dq_oe    : out    vl_logic_vector;
        bs_obs_dq_oeb   : out    vl_logic_vector;
        bs_obs_dqs_in   : out    vl_logic_vector;
        bs_obs_dqs_out  : out    vl_logic_vector;
        bs_obs_dqs_n_out: out    vl_logic_vector;
        bs_obs_dqs_oe   : out    vl_logic_vector;
        bs_obs_dqs_oeb  : out    vl_logic_vector;
        bs_obs_dm_rdqs_out: out    vl_logic_vector;
        bs_obs_dram_clk : out    vl_logic_vector;
        bs_obs_dram_clk_n: out    vl_logic_vector;
        bs_obs_dram_rstn: out    vl_logic_vector;
        bs_obs_ba       : out    vl_logic_vector(2 downto 0);
        bs_obs_addr     : out    vl_logic_vector(15 downto 0);
        bs_obs_casn     : out    vl_logic;
        bs_obs_rasn     : out    vl_logic;
        bs_obs_wen      : out    vl_logic;
        bs_obs_csn      : out    vl_logic_vector;
        bs_obs_cke      : out    vl_logic_vector;
        bs_obs_odt      : out    vl_logic_vector;
        bs_ctl_dm_oeb   : in     vl_logic_vector;
        bs_ctl_dm_oeb_sel: in     vl_logic_vector;
        bs_obs_dm_oeb   : out    vl_logic_vector;
        bs_ctl_dm_oe    : in     vl_logic_vector;
        bs_ctl_dm_oe_sel: in     vl_logic_vector;
        bs_obs_dm_oe    : out    vl_logic_vector;
        bs_obs_dm_in    : out    vl_logic_vector;
        fifo_we_in      : in     vl_logic_vector;
        fifo_we_out     : out    vl_logic_vector;
        local_odt_bit1_dq: out    vl_logic_vector;
        local_odt_bit0_dq: out    vl_logic_vector;
        dq_in           : in     vl_logic_vector;
        dq_out          : out    vl_logic_vector;
        dq_oe           : out    vl_logic_vector;
        dq_oeb          : out    vl_logic_vector;
        local_odt_bit1_dqs: out    vl_logic_vector;
        local_odt_bit0_dqs: out    vl_logic_vector;
        local_odt_bit1_fifo_we_in: out    vl_logic_vector;
        local_odt_bit0_fifo_we_in: out    vl_logic_vector;
        local_odt_bit1_dm: out    vl_logic_vector;
        local_odt_bit0_dm: out    vl_logic_vector;
        dqs_in          : in     vl_logic_vector;
        dqs_out         : out    vl_logic_vector;
        dqs_oe          : out    vl_logic_vector;
        dqs_oeb         : out    vl_logic_vector;
        dm_rdqs_out     : out    vl_logic_vector;
        dm_in           : in     vl_logic_vector;
        dm_oe           : out    vl_logic_vector;
        dm_oeb          : out    vl_logic_vector;
        dqs_out_n       : out    vl_logic_vector;
        dram_clk        : out    vl_logic_vector;
        dram_clk_n      : out    vl_logic_vector;
        dram_rstn       : out    vl_logic_vector;
        ba              : out    vl_logic_vector(2 downto 0);
        addr            : out    vl_logic_vector(15 downto 0);
        casn            : out    vl_logic;
        rasn            : out    vl_logic;
        wen             : out    vl_logic;
        csn             : out    vl_logic_vector;
        cke             : out    vl_logic_vector;
        odt             : out    vl_logic_vector
    );
    attribute mti_svvh_generic_type : integer;
    attribute mti_svvh_generic_type of NUM_DATA_SLICES : constant is 1;
    attribute mti_svvh_generic_type of PHY_CORE_WIDTH : constant is 1;
    attribute mti_svvh_generic_type of PHY_DQ_WIDTH : constant is 1;
    attribute mti_svvh_generic_type of PHY_DRAM_WIDTH : constant is 3;
    attribute mti_svvh_generic_type of UNUSED_SLICE_BITS : constant is 3;
    attribute mti_svvh_generic_type of NUM_MDLL : constant is 3;
    attribute mti_svvh_generic_type of NUM_RANKS : constant is 1;
    attribute mti_svvh_generic_type of CLKSIZE : constant is 1;
    attribute mti_svvh_generic_type of PHY_CTRL_CMD_BITS_PER_SLICE : constant is 1;
    attribute mti_svvh_generic_type of PHY_CTRL_CMD_BITS : constant is 3;
    attribute mti_svvh_generic_type of NUM_PHY_CTRL_SLICES : constant is 1;
    attribute mti_svvh_generic_type of NUM_PHY_CTRL_ZERO : constant is 1;
    attribute mti_svvh_generic_type of NUM_FIFO_WE_OUT_DELAYS : constant is 3;
    attribute mti_svvh_generic_type of NUM_FIFO_WE : constant is 3;
end dfi_phy_core;
