library verilog;
use verilog.vl_types.all;
entity phy_data is
    port(
        core_clk        : in     vl_logic;
        rstn_n          : in     vl_logic;
        rstn_p          : in     vl_logic;
        slice_in_use_n  : in     vl_logic;
        at_spd_atpg     : in     vl_logic;
        clk_stall_level : in     vl_logic;
        bl2             : in     vl_logic;
        test_enable     : in     vl_logic;
        scan_enable     : in     vl_logic;
        select_all_1_rd : in     vl_logic;
        select_all_1_wr : in     vl_logic;
        wr_level_start  : in     vl_logic;
        wr_level_done   : in     vl_logic;
        dqs_pulse       : in     vl_logic;
        wr_dqs_sr_c     : in     vl_logic_vector(6 downto 0);
        wr_dqs_sr_f     : in     vl_logic_vector(1 downto 0);
        wr_data_sr_c    : in     vl_logic_vector(6 downto 0);
        wr_data_sr_f    : in     vl_logic_vector(1 downto 0);
        rd_dqs_sr_c     : in     vl_logic_vector(6 downto 0);
        rd_dqs_sr_f     : in     vl_logic_vector(1 downto 0);
        fifo_we_in_sr_c : in     vl_logic_vector(6 downto 0);
        fifo_we_in_sr_f : in     vl_logic_vector(1 downto 0);
        dll_calib_rst   : in     vl_logic;
        rdc_we_to_re_delay: in     vl_logic_vector(3 downto 0);
        dfi_phy_wdata_en: in     vl_logic;
        dfi_phy_wdata   : in     vl_logic_vector(15 downto 0);
        phy_dfi_rdata   : out    vl_logic_vector(15 downto 0);
        bs_dq           : in     vl_logic_vector(7 downto 0);
        bs_dq_sel       : in     vl_logic_vector(7 downto 0);
        bs_dq_observe   : out    vl_logic_vector(7 downto 0);
        bs_dqoe         : in     vl_logic_vector(7 downto 0);
        bs_dqoe_sel     : in     vl_logic_vector(7 downto 0);
        bs_dqoe_observe : out    vl_logic_vector(7 downto 0);
        bs_dqoeb        : in     vl_logic_vector(7 downto 0);
        bs_dqoeb_sel    : in     vl_logic_vector(7 downto 0);
        bs_dqoeb_observe: out    vl_logic_vector(7 downto 0);
        dfi_phy_dm      : in     vl_logic_vector(1 downto 0);
        phy_bist_dm_rdata: out    vl_logic_vector(1 downto 0);
        use_fixed_re    : in     vl_logic;
        rd_fifo_empty   : out    vl_logic;
        wp_gray         : out    vl_logic_vector(2 downto 0);
        re_with_not_empty: in     vl_logic;
        phy_dfi_rdatavld: out    vl_logic;
        dfi_phy_rdata_en: in     vl_logic;
        dfi_phy_rdlvl_gate_en: in     vl_logic;
        bs_dm           : in     vl_logic;
        bs_dm_sel       : in     vl_logic;
        bs_dm_observe   : out    vl_logic;
        bs_dmoe         : in     vl_logic;
        bs_dmoe_sel     : in     vl_logic;
        bs_dmoe_observe : out    vl_logic;
        bs_dmoeb        : in     vl_logic;
        bs_dmoeb_sel    : in     vl_logic;
        bs_dmoeb_observe: out    vl_logic;
        bs_dqs          : in     vl_logic;
        bs_dqs_sel      : in     vl_logic;
        bs_dqs_observe  : out    vl_logic;
        bs_dqs_n        : in     vl_logic;
        bs_dqs_n_sel    : in     vl_logic;
        bs_dqs_n_observe: out    vl_logic;
        bs_dqsoe        : in     vl_logic;
        bs_dqsoe_sel    : in     vl_logic;
        bs_dqsoe_observe: out    vl_logic;
        bs_dqsoeb       : in     vl_logic;
        bs_dqsoeb_sel   : in     vl_logic;
        bs_dqsoeb_observe: out    vl_logic;
        bs_fifoweout    : in     vl_logic;
        bs_fifoweout_sel: in     vl_logic;
        bs_fifoweout_observe: out    vl_logic;
        reg_phy_rd_local_odt: in     vl_logic_vector(1 downto 0);
        reg_phy_wr_local_odt: in     vl_logic_vector(1 downto 0);
        reg_phy_idle_local_odt: in     vl_logic_vector(1 downto 0);
        reg_phy_dif_on  : in     vl_logic_vector(3 downto 0);
        reg_phy_dif_off : in     vl_logic_vector(3 downto 0);
        reg_phy_dif_sel : in     vl_logic;
        difen_dq0       : out    vl_logic_vector(3 downto 0);
        difen_dq1       : out    vl_logic_vector(3 downto 0);
        difen_dq2       : out    vl_logic_vector(3 downto 0);
        difen_dq3       : out    vl_logic_vector(3 downto 0);
        difen_dm        : out    vl_logic_vector(3 downto 0);
        difen_dqs       : out    vl_logic_vector(3 downto 0);
        local_odt_dq0   : out    vl_logic_vector(1 downto 0);
        local_odt_dq1   : out    vl_logic_vector(1 downto 0);
        local_odt_dq2   : out    vl_logic_vector(1 downto 0);
        local_odt_dq3   : out    vl_logic_vector(1 downto 0);
        local_odt_dqs   : out    vl_logic_vector(1 downto 0);
        local_odt_dm    : out    vl_logic_vector(1 downto 0);
        local_odt_fifo_we_in: out    vl_logic_vector(1 downto 0);
        difen_dq4       : out    vl_logic_vector(3 downto 0);
        difen_dq5       : out    vl_logic_vector(3 downto 0);
        difen_dq6       : out    vl_logic_vector(3 downto 0);
        difen_dq7       : out    vl_logic_vector(3 downto 0);
        local_odt_dq4   : out    vl_logic_vector(1 downto 0);
        local_odt_dq5   : out    vl_logic_vector(1 downto 0);
        local_odt_dq6   : out    vl_logic_vector(1 downto 0);
        local_odt_dq7   : out    vl_logic_vector(1 downto 0);
        dq_out          : out    vl_logic_vector(7 downto 0);
        dq_oe           : out    vl_logic_vector(7 downto 0);
        dq_oeb          : out    vl_logic_vector(7 downto 0);
        dq_in           : in     vl_logic_vector(7 downto 0);
        bs_dq_in_observe: out    vl_logic_vector(7 downto 0);
        dqs_out         : out    vl_logic;
        dqs_out_n       : out    vl_logic;
        dqs_oe          : out    vl_logic;
        dqs_oeb         : out    vl_logic;
        dm_rdqs_out     : out    vl_logic;
        dm_oe           : out    vl_logic;
        dm_oeb          : out    vl_logic;
        dm_in           : in     vl_logic;
        bs_dmin_observe : out    vl_logic;
        fifo_we_out     : out    vl_logic;
        dqs_in          : in     vl_logic;
        bs_dqs_in_observe: out    vl_logic;
        fifo_we_in      : in     vl_logic;
        dqs_in_gate     : out    vl_logic;
        dqs_in_gate_valid: out    vl_logic;
        bs_fifowein_observe: out    vl_logic;
        scan_in_p0      : in     vl_logic;
        scan_out_p0     : out    vl_logic;
        scan_in_p1      : in     vl_logic;
        scan_out_p1     : out    vl_logic;
        scan_in_p2      : in     vl_logic;
        scan_out_p2     : out    vl_logic;
        scan_in_p3      : in     vl_logic;
        scan_out_p3     : out    vl_logic;
        scan_in_n0      : in     vl_logic;
        scan_out_n0     : out    vl_logic
    );
end phy_data;
