library verilog;
use verilog.vl_types.all;
entity serial_gen is
    port(
        pclk            : in     vl_logic;
        presetn         : in     vl_logic;
        psel            : in     vl_logic;
        pwrite          : in     vl_logic;
        penable         : in     vl_logic;
        pwdata          : in     vl_logic_vector(31 downto 0);
        paddr           : in     vl_logic_vector(9 downto 0);
        prdata          : out    vl_logic_vector(31 downto 0);
        pready          : out    vl_logic;
        pbits           : in     vl_logic_vector(609 downto 0);
        fbits           : in     vl_logic_vector(0 downto 0);
        testmode        : in     vl_logic;
        core_up         : in     vl_logic;
        flash_valid     : in     vl_logic;
        factory_mode    : in     vl_logic;
        PLL_REF_DIVISOR : out    vl_logic_vector(5 downto 0);
        PLL_FEEDBACK_DIVISOR: out    vl_logic_vector(9 downto 0);
        PLL_OUTPUT_DIVISOR: out    vl_logic_vector(2 downto 0);
        PLL_FILTER_RANGE: out    vl_logic_vector(3 downto 0);
        PLL_LOCKWIN     : out    vl_logic_vector(2 downto 0);
        PLL_LOCKCNT     : out    vl_logic_vector(3 downto 0);
        PLL_RESET       : out    vl_logic;
        PLL_BYPASS      : out    vl_logic;
        PLL_MODE_1V2    : out    vl_logic;
        PLL_MODE_3V3    : out    vl_logic;
        PLL_FSE         : out    vl_logic;
        PLL_PD          : out    vl_logic;
        PCIE_CTLR_SOFTRESET: out    vl_logic;
        XAUI_CTRL_SOFTRESET: out    vl_logic;
        SERDES_LANE0_SOFTRESET: out    vl_logic;
        SERDES_LANE1_SOFTRESET: out    vl_logic;
        SERDES_LANE2_SOFTRESET: out    vl_logic;
        SERDES_LANE3_SOFTRESET: out    vl_logic;
        SPLL_LOCK_INT_ENABLE: out    vl_logic;
        SPLL_LOCKLOST_INT_ENABLE: out    vl_logic;
        FPLL_LOCK_INT_ENABLE: out    vl_logic;
        FPLL_LOCKLOST_INT_ENABLE: out    vl_logic;
        CFGR_AXI_AHB_MASTER: out    vl_logic;
        CFGR_AXI_AHB_SLAVE: out    vl_logic;
        CFGR_PCIE_ECC_EN: out    vl_logic_vector(2 downto 0);
        CFGR_PCIE_ECC_INTR_EN: out    vl_logic_vector(2 downto 0);
        CONFIG_TEST_IN  : out    vl_logic_vector(31 downto 0);
        TEST_OUT_READ_ADDR: out    vl_logic_vector(4 downto 0);
        CFGR_SLOT_CONFIG: out    vl_logic;
        CFGR_PM_AUX_PWR : out    vl_logic;
        CFGR_L2_P2_ENABLE: out    vl_logic;
        CFGR_TX_SWING   : out    vl_logic;
        CONFIG_PHY_MODE : out    vl_logic_vector(15 downto 0);
        CONFIG_ECPS_SEL : out    vl_logic_vector(3 downto 0);
        CONFIG_LINKK2LANE: out    vl_logic_vector(3 downto 0);
        CONFIG_REG_LANE_SEL: out    vl_logic_vector(3 downto 0);
        CONFIG_REXT_SEL : out    vl_logic_vector(7 downto 0);
        PCIE_VENDOR_ID  : out    vl_logic_vector(15 downto 0);
        PCIE_DEVICE_ID  : out    vl_logic_vector(15 downto 0);
        PCIE_SUB_VENDOR_ID: out    vl_logic_vector(15 downto 0);
        PCIE_SUB_DEVICE_ID: out    vl_logic_vector(15 downto 0);
        PCIE_REV_ID     : out    vl_logic_vector(15 downto 0);
        PCIE_CLASS_CODE : out    vl_logic_vector(15 downto 0);
        K_BRIDGE_SPEED  : out    vl_logic;
        K_BRIDGE_EMPH   : out    vl_logic;
        K_BRIDGE_SPEC_REV: out    vl_logic_vector(1 downto 0);
        CONFIG_BAR_CONTROL_0: out    vl_logic_vector(3 downto 0);
        CONFIG_BAR_SIZE_0: out    vl_logic_vector(4 downto 0);
        CONFIG_BAR_CONTROL_1: out    vl_logic_vector(3 downto 0);
        CONFIG_BAR_SIZE_1: out    vl_logic_vector(4 downto 0);
        CONFIG_BAR_CONTROL_2: out    vl_logic_vector(3 downto 0);
        CONFIG_BAR_SIZE_2: out    vl_logic_vector(4 downto 0);
        CONFIG_BAR_CONTROL_3: out    vl_logic_vector(3 downto 0);
        CONFIG_BAR_SIZE_3: out    vl_logic_vector(4 downto 0);
        CONFIG_BAR_CONTROL_4: out    vl_logic_vector(3 downto 0);
        CONFIG_BAR_SIZE_4: out    vl_logic_vector(4 downto 0);
        CONFIG_BAR_CONTROL_5: out    vl_logic_vector(3 downto 0);
        CONFIG_BAR_SIZE_5: out    vl_logic_vector(4 downto 0);
        PLL_LOCK        : in     vl_logic;
        FAB_PLL_LOCK    : in     vl_logic;
        FABCALIBFAIL    : in     vl_logic_vector(1 downto 0);
        TEST_OUT_READ_DATA: in     vl_logic_vector(31 downto 0);
        PLL_LOCK_INT_SET: in     vl_logic;
        PLL_LOCK_INT    : out    vl_logic;
        PLL_LOCKLOST_INT_SET: in     vl_logic;
        PLL_LOCKLOST_INT: out    vl_logic;
        SERDESIF_INTR_STATUS_SET: in     vl_logic_vector(5 downto 0);
        SERDESIF_INTR_STATUS: out    vl_logic_vector(5 downto 0);
        FABCALIBSTART   : out    vl_logic_vector(1 downto 0);
        LANE01_REFCLK_SEL: out    vl_logic_vector(1 downto 0);
        LANE23_REFCLK_SEL: out    vl_logic_vector(1 downto 0);
        PCIE_CORECLK_SEL: out    vl_logic_vector(1 downto 0);
        PIPE_PCLKIN_LANE01_SEL: out    vl_logic_vector(1 downto 0);
        PIPE_PCLKIN_LANE23_SEL: out    vl_logic_vector(1 downto 0);
        FABRIC_EPCS_RSTN_SEL: out    vl_logic_vector(3 downto 0);
        GEN2_SUPPORTED  : out    vl_logic;
        MBIST_CLK_SEL   : out    vl_logic;
        SERDES_TEST_OUT : in     vl_logic_vector(31 downto 0);
        FATC_RESET      : out    vl_logic;
        RC_OSC_REFCLK_SEL: out    vl_logic;
        PLL_SERDESIF_SSE: out    vl_logic;
        PLL_SERDESIF_SSMD: out    vl_logic_vector(1 downto 0);
        PLL_SERDESIF_SSMF: out    vl_logic_vector(4 downto 0);
        CONF_AXI_MSTR_WNDW_0: out    vl_logic_vector(31 downto 0);
        CONF_AXI_MSTR_WNDW_1: out    vl_logic_vector(31 downto 0);
        CONF_AXI_MSTR_WNDW_2: out    vl_logic_vector(31 downto 0);
        CONF_AXI_MSTR_WNDW_3: out    vl_logic_vector(3 downto 0);
        CONF_AXI_SLV_WNDW_0: out    vl_logic_vector(31 downto 0);
        CONF_AXI_SLV_WNDW_1: out    vl_logic_vector(31 downto 0);
        CONF_AXI_SLV_WNDW_2: out    vl_logic_vector(31 downto 0);
        CONF_AXI_SLV_WNDW_3: out    vl_logic_vector(2 downto 0);
        DESKEW_PLL_REF_CLK: out    vl_logic_vector(1 downto 0);
        DESKEW_PLL_FDB_CLK: out    vl_logic_vector(1 downto 0);
        DEBUG_MODE_KEY  : out    vl_logic_vector(7 downto 0);
        ATSPEED_CLK_SEL : out    vl_logic;
        EXTRA_BITS      : out    vl_logic_vector(7 downto 0)
    );
end serial_gen;
